==> manydhcp2.5.2.tar.bz2: manydhcp/service/wake.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////

$lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

if(!isset($title)) $title = $TEXT['menu-btn35'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

$delimiter =".";
$n = 0;

//function disabled by php > 5.5.3
////import_request_variables("gP", "in_");
// before using only ->  while(list($id,$value) = @each($in_ip))
 while(list($id2,$value2) = @each($_POST)) {
  if($id2 == "ip") {
   while(list($id,$value) = each($value2)) {
     if($id > 0 && $value == 'on')
     {
      $query3 = "SELECT ip_addr, hw FROM `tbl_ip` WHERE `ip_id`= $id";
       $result3 = mysql_query($query3);
        if(!$result3) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
         $result4 = mysql_fetch_array($result3,MYSQL_ASSOC);

         $addr = explode($delimiter,$result4['ip_addr'],4);
           $oct1 = substr($addr['0'],0,1);
            if($oct1 == '0')
             {
              $oct_res1 = substr($addr['0'],1,1);
               if($oct_res1 == '0')
                {
                 $oct_result1 = substr($addr['0'],2,3);
                } else $oct_result1 = substr($addr['0'],1,3);
              } else $oct_result1 = $addr['0'];
           $oct2 = substr($addr['1'],0,1);
            if($oct2 == '0')
             {
              $oct_res2 = substr($addr['1'],1,1);
               if($oct_res2 == '0')
                {
                $oct_result2 = substr($addr['1'],2,3);
                } else $oct_result2 = substr($addr['1'],1,3);
              } else $oct_result2 = $addr['1'];
           $oct3 = substr($addr['2'],0,1);
            if($oct3 == '0')
             {
             $oct_res3 = substr($addr['2'],1,1);
               if($oct_res3 == '0')
                {
                $oct_result3 = substr($addr['2'],2,3);
                } else $oct_result3 = substr($addr['2'],1,3);
              } else $oct_result3 = $addr['2'];
           $oct4 = substr($addr['3'],0,1);
            if($oct4 == '0')
             {
             $oct_res4 = substr($addr['3'],1,1);
              if($oct_res4 == '0')
               {
               $oct_result4 = substr($addr['3'],2,3);
               } else $oct_result4 = substr($addr['3'],1,3);
             } else $oct_result4 = $addr['3'];
        $ip_addres = $oct_result1.".".$oct_result2.".".$oct_result3.".".$oct_result4;
        $mac = substr(chunk_split($result4['hw'],2,":"),0,-1);
        $addres = "255.255.255.255";
        $socket_number = "9";
       flush();
       WakeOnLan($addres,$mac,$socket_number);

     $n++;
     }
   }
  }
 }
//*************************************
//Информация для лога
$ip = $_SERVER['REMOTE_ADDR'];
$doing = $TEXT['log-addr9'];
$what = $TEXT['log-grp-wake'].$n.$TEXT['log-grp-zadr4'];
$who = $result2['familiya']." ".$result2['name'];
//*************************************
$query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
   if(mysql_query($query2))
    {
    echo "<html><head>
          <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=../addresses/index.php' />
          </head></html>";
    } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.7.2.tar.bz2: manydhcp/service/wake.php <==
<?php
///////////////////////////////////////////////////
//2010 (C)
//Карпухин Павел
///////////////////////////////////////////////////

$lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

$title = $TEXT['menu-btn35'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}

$delimiter =".";
$n = 0;

//function disabled by php > 5.5.3
////import_request_variables("gP", "in_");
// before using only ->  while(list($id,$value) = @each($in_ip))
 while(list($id2,$value2) = each($_POST)) {
  if($id2 == "ip") {
   while(list($id,$value) = each($value2)) {
     if($id > 0 && $value == 'on')
     {
      $query3 = "SELECT ip_addr, hw FROM `tbl_ip` WHERE `ip_id`= $id";
       $result3 = mysqli_query($dbcnx,$query3);
        if(!$result3) {puterror($result2['skin'],$TEXT['error-tbl2']); require_once "../utils/bottom_adm.php"; exit();}
         $result4 = mysqli_fetch_array($result3,MYSQLI_ASSOC);

         $addr = explode($delimiter,$result4['ip_addr'],4);
           $oct1 = substr($addr['0'],0,1);
            if($oct1 == '0')
             {
              $oct_res1 = substr($addr['0'],1,1);
               if($oct_res1 == '0')
                {
                 $oct_result1 = substr($addr['0'],2,3);
                } else {$oct_result1 = substr($addr['0'],1,3);}
              } else {$oct_result1 = $addr['0'];}
           $oct2 = substr($addr['1'],0,1);
            if($oct2 == '0')
             {
              $oct_res2 = substr($addr['1'],1,1);
               if($oct_res2 == '0')
                {
                $oct_result2 = substr($addr['1'],2,3);
                } else {$oct_result2 = substr($addr['1'],1,3);}
              } else {$oct_result2 = $addr['1'];}
           $oct3 = substr($addr['2'],0,1);
            if($oct3 == '0')
             {
             $oct_res3 = substr($addr['2'],1,1);
               if($oct_res3 == '0')
                {
                $oct_result3 = substr($addr['2'],2,3);
                } else {$oct_result3 = substr($addr['2'],1,3);}
              } else {$oct_result3 = $addr['2'];}
           $oct4 = substr($addr['3'],0,1);
            if($oct4 == '0')
             {
             $oct_res4 = substr($addr['3'],1,1);
              if($oct_res4 == '0')
               {
               $oct_result4 = substr($addr['3'],2,3);
               } else {$oct_result4 = substr($addr['3'],1,3);}
             } else {$oct_result4 = $addr['3'];}
        $ip_addres = $oct_result1.".".$oct_result2.".".$oct_result3.".".$oct_result4;
        $mac = substr(chunk_split($result4['hw'],2,":"),0,-1);
        $addres = "255.255.255.255";
        $socket_number = "9";
       flush();
       WakeOnLan($addres,$mac,$socket_number);

     $n++;
     }
   }
  }
 }
//*************************************
//Информация для лога
$ip = $_SERVER['REMOTE_ADDR'];
$doing = $TEXT['log-addr9'];
$what = $TEXT['log-grp-wake'].$n.$TEXT['log-grp-zadr4'];
$who = $result2['familiya']." ".$result2['name'];
//*************************************
$query2 = "INSERT INTO tbl_logs ( `log_id` , `data` , `ip` , `who` , `doing` , `what` ) VALUES ( NULL , NOW() , '$ip' , '$who' , '$doing' , '$what')";
   if(mysqli_query($dbcnx,$query2))
    {
    echo "<html><head>
          <meta HTTP-EQUIV='Refresh' CONTENT='0; URL=../addresses/index.php' />
          </head></html>";
    } else {puterror($result2['skin'],$TEXT['error-log']); require_once "../utils/bottom_adm.php"; exit();}
require_once "../utils/bottom_adm.php";
?>
